The pylife-odbclient package
============================

.. include:: ../../../tools/odbclient/README.md
   :parser: myst_parser.sphinx_


API docs
--------
.. toctree::
   :maxdepth: 1

   odbclient
